@@ -11,6 +11,7 @@ from yaml.representer import SafeRepresenter
 
 from esque.resources.topic import Topic, TopicDiff, Watermark
 
+C_MAX_INT = 2 ** 31 - 1
 MILLISECONDS_PER_YEAR = 1000 * 3600 * 24 * 365
 
 
@@ -121,7 +122,7 @@ def pretty_duration(value: Any, *, multiplier: int = 1) -> str:
     value *= multiplier
 
     # Fix for conversion errors of ms > C_MAX_INT in some internal lib
-    if value > MILLISECONDS_PER_YEAR:
+    if value > C_MAX_INT:
         value = int(value / MILLISECONDS_PER_YEAR)
         return pendulum.duration(years=value).in_words()
 
